{% load fleetfinder_versioned_static %}

<link rel="stylesheet" href="{% fleetfinder_static 'fleetfinder/css/aa-bootstrap-fix.min.css' %}">
<link rel="stylesheet" href="{% fleetfinder_static 'fleetfinder/css/fleetfinder.min.css' %}">
