{% load i18n %}

<nav class="navbar navbar-default">
    <div class="container-fluid">
        <div class="navbar-header">
            <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                <span class="sr-only">{% translate "Toggle navigation" %}</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>

            <a class="navbar-brand" href="{% url 'fleetfinder:dashboard' %}">
                {% translate "Available fleets" as navigation_item %}
                {{ navigation_item|title }}
            </a>
        </div>

        <ul class="nav navbar-nav">
            {% if perms.fleetfinder.manage_fleets %}
                <li>
                    <a href="{% url 'fleetfinder:create_fleet' %}">
                        {% translate "Create fleet" as navigation_item %}
                        {{ navigation_item|title }}
                    </a>
                </li>
            {% endif %}
        </ul>
    </div>
</nav>
